@@ -1,10 +1,10 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .MultiElementContainer import *
-from .Scrollbar import *
-from .SettingsOverlay import *
-from .SettingsOverlay_SettingField import *
+from .MultiElementContainer import MultiElementContainer
+from .Scrollbar import Scrollbar
+from .SettingsOverlay import SettingsOverlay
+from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
 
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
