@@ -1,18 +1,20 @@
 from typing import overload
-from typing import List
 from typing import TypeVar
-from .Core import *
-from .BaseEventRegistry import *
-from .BaseEvent import *
+from typing import Set
+from .Core import Core
+from .BaseEventRegistry import BaseEventRegistry
+from .BaseEvent import BaseEvent
 
-Set = TypeVar["java.util.Set_java.lang.Thread_"]
 Throwable = TypeVar["java.lang.Throwable"]
 Logger = TypeVar["org.apache.logging.log4j.Logger"]
 Thread = TypeVar["java.lang.Thread"]
 
 class BaseProfile:
+	"""
+	Since: 1.2.7 
+	"""
 	LOGGER: Logger
-	joinedThreadStack: List[Thread]
+	joinedThreadStack: Set[Thread]
 	profileName: str
 
 	@overload
@@ -25,30 +27,73 @@ class BaseProfile:
 
 	@overload
 	def getRegistry(self) -> BaseEventRegistry:
+		"""
+		Since: 1.1.2 [citation needed] 
+		"""
+		pass
+
+	@overload
+	def checkJoinedThreadStack(self) -> bool:
+		"""
+		Since: 1.6.0 
+		"""
 		pass
 
 	@overload
 	def loadOrCreateProfile(self, profileName: str) -> None:
+		"""
+		Since: 1.1.2 [citation needed] 
+
+		Args:
+			profileName: 
+		"""
 		pass
 
 	@overload
 	def saveProfile(self) -> None:
+		"""
+		Since: 1.0.8 [citation needed] 
+		"""
 		pass
 
 	@overload
 	def triggerEvent(self, event: BaseEvent) -> None:
+		"""
+		Since: 1.2.7 
+
+		Args:
+			event: 
+		"""
 		pass
 
 	@overload
 	def triggerEventJoin(self, event: BaseEvent) -> None:
+		"""
+		Since: 1.2.7 
+
+		Args:
+			event: 
+		"""
 		pass
 
 	@overload
 	def triggerEventNoAnything(self, event: BaseEvent) -> None:
+		"""
+		Since: 1.2.7 
+
+		Args:
+			event: 
+		"""
 		pass
 
 	@overload
 	def triggerEventJoinNoAnything(self, event: BaseEvent) -> None:
+		"""
+		Since: 1.2.7 
+
+		Args:
+			event: 
+		"""
 		pass
 
 	@overload
