@@ -1,8 +1,8 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .AbstractMapSettingContainer_MapSettingEntry import *
-from .ColorMapSetting import *
+from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
+from .ColorMapSetting import ColorMapSetting
 
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
