@@ -1,9 +1,11 @@
 from typing import overload
-from .CommandBuilder import *
-from .MethodWrapper import *
+from .MethodWrapper import MethodWrapper
 
 
 class CommandBuilder:
+	"""
+	Since: 1.4.2 
+	"""
 
 	@overload
 	def __init__(self, name: str) -> None:
@@ -102,11 +104,28 @@ class CommandBuilder:
 		pass
 
 	@overload
-	def or(self) -> "CommandBuilder":
+	def or_(self) -> "CommandBuilder":
 		pass
 
 	@overload
-	def or(self, argumentLevel: int) -> "CommandBuilder":
+	def otherwise(self) -> "CommandBuilder":
+		"""name overload for CommandBuilder#or() to work around language keyword restrictions\n
+		Since: 1.5.2 
+		"""
+		pass
+
+	@overload
+	def or_(self, argumentLevel: int) -> "CommandBuilder":
+		pass
+
+	@overload
+	def otherwise(self, argLevel: int) -> "CommandBuilder":
+		"""name overload for CommandBuilder#or(int) to work around language keyword restrictions\n
+		Since: 1.5.2 
+
+		Args:
+			argLevel: 
+		"""
 		pass
 
 	@overload
