@@ -1,12 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseHelper import *
-from .CommandContextHelper import *
+from .BaseHelper import BaseHelper
 
 CommandContext = TypeVar["com.mojang.brigadier.context.CommandContext_net.fabricmc.fabric.api.client.command.v1.FabricClientCommandSource_"]
 StringRange = TypeVar["com.mojang.brigadier.context.StringRange"]
 
 class CommandContextHelper(BaseHelper):
+	"""
+	Since: 1.4.2 
+	"""
 
 	@overload
 	def __init__(self, base: CommandContext) -> None:
@@ -14,6 +16,12 @@ class CommandContextHelper(BaseHelper):
 
 	@overload
 	def getArg(self, name: str) -> object:
+		"""
+		Since: 1.4.2 
+
+		Args:
+			name: 
+		"""
 		pass
 
 	@overload
