@@ -1,8 +1,11 @@
 from typing import overload
-from .BaseEvent import *
+from .BaseEvent import BaseEvent
 
 
 class EventDeath(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 
 	@overload
 	def __init__(self) -> None:
