@@ -1,8 +1,11 @@
 from typing import overload
-from .BaseEvent import *
+from .BaseEvent import BaseEvent
 
 
 class EventEXPChange(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	progress: float
 	total: int
 	level: int
