@@ -1,11 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .ClientPlayerEntityHelper import *
+from .BaseEvent import BaseEvent
+from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
 
 ClientPlayerEntity = TypeVar["net.minecraft.client.network.ClientPlayerEntity"]
 
 class EventJoinServer(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	player: ClientPlayerEntityHelper
 	address: str
 
