@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .AbstractMapSettingContainer_MapSettingEntry import *
-from .FileMapSetting import *
+from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
+from .FileMapSetting import FileMapSetting
 
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
