@@ -1,10 +1,12 @@
 from typing import overload
 from typing import TypeVar
-from .SelectCursor import *
+from .SelectCursor import SelectCursor
 
 Consumer = TypeVar["java.util.function.Consumer_java.lang.String_"]
 
 class History:
+	"""
+	"""
 	onChange: Consumer
 	current: str
 
@@ -14,6 +16,15 @@ class History:
 
 	@overload
 	def addChar(self, position: int, content: str) -> bool:
+		"""
+
+		Args:
+			position: 
+			content: 
+
+		Returns:
+			is new step. 
+		"""
 		pass
 
 	@overload
@@ -22,10 +33,26 @@ class History:
 
 	@overload
 	def deletePos(self, position: int, length: int) -> bool:
+		"""
+
+		Args:
+			position: 
+
+		Returns:
+			is new step. 
+		"""
 		pass
 
 	@overload
 	def bkspacePos(self, position: int, length: int) -> bool:
+		"""
+
+		Args:
+			position: 
+
+		Returns:
+			is new step 
+		"""
 		pass
 
 	@overload
@@ -42,10 +69,20 @@ class History:
 
 	@overload
 	def undo(self) -> int:
+		"""
+
+		Returns:
+			position of step. -1 if nothing to undo. 
+		"""
 		pass
 
 	@overload
 	def redo(self) -> int:
+		"""
+
+		Returns:
+			position of step. -1 if nothing to redo. 
+		"""
 		pass
 
 	pass
