@@ -1,14 +1,13 @@
 from typing import overload
-from typing import List
 from typing import TypeVar
+from typing import Set
 
-Set = TypeVar["java.util.Set_net.minecraft.util.Identifier_"]
 Identifier = TypeVar["net.minecraft.util.Identifier"]
 
 class IFontManager:
 
 	@overload
-	def jsmacros_getFontList(self) -> List[Identifier]:
+	def jsmacros_getFontList(self) -> Set[Identifier]:
 		pass
 
 	pass
