@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .IContainerParent import *
-from .OverlayContainer import *
+from .IContainerParent import IContainerParent
+from .OverlayContainer import OverlayContainer
 
 Element = TypeVar["net.minecraft.client.gui.Element"]
 
