@@ -1,12 +1,13 @@
 from typing import overload
 from typing import TypeVar
-from .BaseLanguage import *
-from .Core import *
-from .BaseWrappedException import *
-from .BaseEvent import *
-from .JSScriptContext import *
+from .BaseLanguage import BaseLanguage
+from .Core import Core
+from .BaseWrappedException import BaseWrappedException
+from .BaseEvent import BaseEvent
+from .JSScriptContext import JSScriptContext
 
 Throwable = TypeVar["java.lang.Throwable"]
+File = TypeVar["java.io.File"]
 
 class JavascriptLanguageDefinition(BaseLanguage):
 
@@ -19,7 +20,7 @@ class JavascriptLanguageDefinition(BaseLanguage):
 		pass
 
 	@overload
-	def createContext(self, event: BaseEvent) -> JSScriptContext:
+	def createContext(self, event: BaseEvent, file: File) -> JSScriptContext:
 		pass
 
 	pass
