@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .MultiElementContainer import *
-from .ScriptTrigger import *
-from .MacroScreen import *
+from .MultiElementContainer import MultiElementContainer
+from .ScriptTrigger import ScriptTrigger
+from .MacroScreen import MacroScreen
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 Text = TypeVar["net.minecraft.text.Text"]
