@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .BaseScreen import *
-from .ScriptTrigger import *
-from .MacroContainer import *
+from .BaseScreen import BaseScreen
+from .ScriptTrigger import ScriptTrigger
+from .MacroContainer import MacroContainer
 
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
