@@ -1,11 +1,10 @@
 from typing import overload
 from typing import TypeVar
 from typing import Mapping
-from .IBossBarHud import *
+from .IBossBarHud import IBossBarHud
 
 ClientBossBar = TypeVar["net.minecraft.client.gui.hud.ClientBossBar"]
 UUID = TypeVar["java.util.UUID"]
-Map = TypeVar["java.util.Map_java.util.UUID,net.minecraft.client.gui.hud.ClientBossBar_"]
 
 class MixinBossBarHud(IBossBarHud):
 
