@@ -1,9 +1,8 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .IRecipeBookResults import *
+from .IRecipeBookResults import IRecipeBookResults
 
-List = TypeVar["java.util.List_net.minecraft.client.gui.screen.recipebook.RecipeResultCollection_"]
 RecipeResultCollection = TypeVar["net.minecraft.client.gui.screen.recipebook.RecipeResultCollection"]
 
 class MixinRecipeBookResults(IRecipeBookResults):
