@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .Draw3D import *
-from .PlayerInput import *
+from .Draw3D import Draw3D
+from .PlayerInput import PlayerInput
 
 ClientPlayerEntity = TypeVar["net.minecraft.client.network.ClientPlayerEntity"]
 
