@@ -1,11 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseHelper import *
-from .TextHelper import *
+from .BaseHelper import BaseHelper
+from .TextHelper import TextHelper
 
 PlayerListEntry = TypeVar["net.minecraft.client.network.PlayerListEntry"]
 
 class PlayerListEntryHelper(BaseHelper):
+	"""
+	Since: 1.0.2 
+	"""
 
 	@overload
 	def __init__(self, p: PlayerListEntry) -> None:
@@ -13,14 +16,23 @@ class PlayerListEntryHelper(BaseHelper):
 
 	@overload
 	def getUUID(self) -> str:
+		"""
+		Since: 1.1.9 
+		"""
 		pass
 
 	@overload
 	def getName(self) -> str:
+		"""
+		Since: 1.0.2 
+		"""
 		pass
 
 	@overload
 	def getDisplayText(self) -> TextHelper:
+		"""
+		Since: 1.1.9 
+		"""
 		pass
 
 	@overload
