@@ -1,11 +1,10 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .AbstractMapSettingContainer import *
-from .SettingsOverlay import *
-from .ScriptTrigger import *
+from .AbstractMapSettingContainer import AbstractMapSettingContainer
+from .SettingsOverlay import SettingsOverlay
+from .ScriptTrigger import ScriptTrigger
 
-List = TypeVar["java.util.List_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
 class ProfileSetting(AbstractMapSettingContainer):
