@@ -1,11 +1,10 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .AbstractMapSettingContainer_MapSettingEntry import *
-from .ProfileSetting import *
-from .ScriptTrigger import *
+from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
+from .ProfileSetting import ProfileSetting
+from .ScriptTrigger import ScriptTrigger
 
-List = TypeVar["java.util.List_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
 class ProfileSetting_ProfileEntry(AbstractMapSettingContainer_MapSettingEntry):
