@@ -1,13 +1,15 @@
 from typing import overload
 from typing import TypeVar
-from .RenderCommon_RenderElement import *
-from .TextHelper import *
-from .RenderCommon_Text import *
+from .RenderCommon_RenderElement import RenderCommon_RenderElement
+from .TextHelper import TextHelper
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 Text = TypeVar["net.minecraft.text.Text"]
 
 class RenderCommon_Text(RenderCommon_RenderElement):
+	"""
+	Since: 1.0.5 
+	"""
 	text: Text
 	scale: float
 	rotation: float
@@ -28,30 +30,67 @@ class RenderCommon_Text(RenderCommon_RenderElement):
 
 	@overload
 	def setScale(self, scale: float) -> "RenderCommon_Text":
+		"""
+		Since: 1.0.5 
+
+		Args:
+			scale: 
+		"""
 		pass
 
 	@overload
 	def setRotation(self, rotation: float) -> "RenderCommon_Text":
+		"""
+		Since: 1.0.5 
+
+		Args:
+			rotation: 
+		"""
 		pass
 
 	@overload
 	def setPos(self, x: int, y: int) -> "RenderCommon_Text":
+		"""
+		Since: 1.0.5 
+
+		Args:
+			x: 
+			y: 
+		"""
 		pass
 
 	@overload
 	def setText(self, text: str) -> "RenderCommon_Text":
+		"""
+		Since: 1.0.5 
+
+		Args:
+			text: 
+		"""
 		pass
 
 	@overload
 	def setText(self, text: TextHelper) -> "RenderCommon_Text":
+		"""
+		Since: 1.2.7 
+
+		Args:
+			text: 
+		"""
 		pass
 
 	@overload
 	def getText(self) -> TextHelper:
+		"""
+		Since: 1.2.7 
+		"""
 		pass
 
 	@overload
 	def getWidth(self) -> int:
+		"""
+		Since: 1.0.5 
+		"""
 		pass
 
 	@overload
