@@ -1,6 +1,5 @@
 from typing import overload
-from .ScriptTrigger_TriggerType import *
-from .ScriptTrigger import *
+from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
 
 
 class ScriptTrigger:
@@ -31,18 +30,30 @@ class ScriptTrigger:
 
 	@overload
 	def getTriggerType(self) -> ScriptTrigger_TriggerType:
+		"""
+		Since: 1.2.7 
+		"""
 		pass
 
 	@overload
 	def getEvent(self) -> str:
+		"""
+		Since: 1.2.7 
+		"""
 		pass
 
 	@overload
 	def getScriptFile(self) -> str:
+		"""
+		Since: 1.2.7 
+		"""
 		pass
 
 	@overload
 	def getEnabled(self) -> bool:
+		"""
+		Since: 1.2.7 
+		"""
 		pass
 
 	pass
