@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .Button import *
+from .Button import Button
 
 Consumer = TypeVar["java.util.function.Consumer_java.lang.String_"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
