@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .OverlayContainer import *
-from .TextInput import *
-from .IOverlayParent import *
+from .OverlayContainer import OverlayContainer
+from .TextInput import TextInput
+from .IOverlayParent import IOverlayParent
 
 Consumer = TypeVar["java.util.function.Consumer_java.lang.String_"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
