@@ -1,12 +1,11 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .BaseHelper import *
-from .VillagerInventory import *
-from .ItemStackHelper import *
-from .NBTElementHelper import *
+from .BaseHelper import BaseHelper
+from .VillagerInventory import VillagerInventory
+from .ItemStackHelper import ItemStackHelper
+from .NBTElementHelper import NBTElementHelper
 
-List = TypeVar["java.util.List_xyz.wagyourtail.jsmacros.client.api.helpers.ItemStackHelper_"]
 TradeOffer = TypeVar["net.minecraft.village.TradeOffer"]
 
 class TradeOfferHelper(BaseHelper):
@@ -17,38 +16,77 @@ class TradeOfferHelper(BaseHelper):
 
 	@overload
 	def getInput(self) -> List[ItemStackHelper]:
+		"""
+
+		Returns:
+			list of input items required 
+		"""
 		pass
 
 	@overload
 	def getOutput(self) -> ItemStackHelper:
+		"""
+
+		Returns:
+			output item that will be recieved 
+		"""
 		pass
 
 	@overload
 	def select(self) -> None:
+		"""select trade offer on screen
+		"""
 		pass
 
 	@overload
 	def isAvailable(self) -> bool:
+		"""
+		"""
 		pass
 
 	@overload
 	def getNBT(self) -> NBTElementHelper:
+		"""
+
+		Returns:
+			trade offer as nbt tag 
+		"""
 		pass
 
 	@overload
 	def getUses(self) -> int:
+		"""
+
+		Returns:
+			current number of uses 
+		"""
 		pass
 
 	@overload
 	def getMaxUses(self) -> int:
+		"""
+
+		Returns:
+			max uses before it locks 
+		"""
 		pass
 
 	@overload
 	def getExperience(self) -> int:
+		"""
+
+		Returns:
+			experience gained for trade 
+		"""
 		pass
 
 	@overload
 	def getCurrentPriceAdjustment(self) -> int:
+		"""
+
+		Returns:
+			current price adjustment, negative is discount. 
+		"""
 		pass
 
 	@overload
